@@ -5,20 +5,28 @@ library(cholera)
 plot(neighborhoodVoronoi())
 
 ## ------------------------------------------------------------------------
-summary(neighborhoodVoronoi())
+# print(neighborhoodVoronoi()) or
+neighborhoodVoronoi()
 
 ## ---- fig.width = 5, fig.height = 5, fig.align = "center", message = FALSE----
-walkingPath(150)
+plot(walkingDistance(150, unit = "meter"))
 
 ## ---- fig.width = 5, fig.height = 5, fig.align = "center", message = FALSE----
 plot(neighborhoodWalking())
 
 ## ------------------------------------------------------------------------
-summary(neighborhoodWalking())
+# print(neighborhoodWalking()) or
+neighborhoodWalking()
 
 ## ---- fig.width = 5, fig.height = 5, fig.align = "center", message = FALSE----
-plot(neighborhoodWalking(), observed = FALSE)
+plot(neighborhoodWalking(case.set = "expected"))
 
 ## ---- fig.width = 5, fig.height = 5, fig.align = "center", message = FALSE----
-plot(neighborhoodWalking(), street = FALSE, observed = FALSE)
+plot(neighborhoodWalking(case.set = "expected"), area = TRUE)
+
+## ---- fig.width = 5, fig.height = 5, fig.align = "center", message = FALSE----
+plot(neighborhoodWalking(-6))
+
+## ---- fig.width = 5, fig.height = 5, fig.align = "center", message = FALSE----
+plot(neighborhoodWalking(-7))
 
