@@ -2,9 +2,6 @@
 knitr::opts_chunk$set(collapse = TRUE, comment = "#>")
 library(cholera)
 
-## ---- fig.width = 5, fig.height = 5, fig.align = "center", echo = TRUE----
-snowMap()
-
 ## ------------------------------------------------------------------------
 head(roads)
 nrow(roads)
